import { Span } from 'opentracing';
import { ConfService, DataRequest, InitConfigFork, ResponseMessage } from './types';
/**
 * Clase base para los Worker y Fork
 */
export default abstract class Base {
    [x: string]: any;
    /**
     * Configuracion del servicio
     * @protected
     */
    protected config: ConfService;
    /**
     * Topico del servicio
     * @protected
     */
    protected Topic: string;
    /**
     * Contructor de la clase
     * @param conf Configuracion del servicio
     */
    constructor(conf: ConfService, topic?: string);
    /**
     * Metodo que hace rel registro de Forks
     * para su utilizacion sobre los servicios.
     * @param conf Configuracion para el evento
     */
    forksConfig(conf: InitConfigFork[]): void;
    /**
     * Metodo que procesa el mensaje del servicio.
     * @abstract
     * @param data Datos del mensaje
     */
    abstract message(span: Span, data: DataRequest, Method: () => void, params: string[]): Promise<any>;
    /**
     * Metodo para dar formato a los mensajes de salida.
     * @param data Datos a enviar
     * @param arg Argumentos extra
     */
    formatResponse(Data: DataRequest, ...arg: any[]): ResponseMessage;
}
